# Design Document

![Schema](dspace.png?raw=true)
## PostgreSQL
PostgreSQL is deployed using official [helm](https://github.com/kubernetes/charts/tree/master/stable/postgresql "helm").
Additional env variables are added :
- dspaceuser
- dspacepassword
- dspacedbname
- dspaceutilsdbname

Other changes:
- added adapt_utilities_sql.sh  to Dockerfile.
- modified commul-customization/init-dspace-dbs.sh to add env params 

### Kubertes cli
How to show **pv** (persistent volume), **pvc** (persistsne volume claim), **po** (pod)
```bash
$ kubectl -n dspace get pv,pvc,po -o wide
NAME                                          CAPACITY   ACCESSMODES   RECLAIMPOLICY   STATUS    CLAIM                             STORAGECLASS   REASON    AGE
pv/pvc-e38405df-97b4-11e7-ba35-b60483de6a40   8Gi        RWO           Delete          Bound     dspace/dspace-postgresql          auto                     7d

NAME                    STATUS    VOLUME                                     CAPACITY   ACCESSMODES   STORAGECLASS   AGE
pvc/dspace-postgresql   Bound     pvc-e38405df-97b4-11e7-ba35-b60483de6a40   8Gi        RWO           auto           7d

NAME                                    READY     STATUS    RESTARTS   AGE       IP            NODE
po/dspace-postgresql-4284405808-xfx5w   1/1       Running   0          6d        10.12.36.39   10.7.2.234


```
## Tomcat
configured two cephfs mount points, so container can scale
- /opt/lindat-dspace
- /opt/repository

Other notes:
- installation is done manually [1]
- tomcat is started manually [2]

```bash
$ kubectl -n dspace get po
NAME                                 READY     STATUS    RESTARTS   AGE
dspace-977584178-m9wsv               1/1       Running   16         16h
dspace-postgresql-4284405808-xfx5w   1/1       Running   0          1d
```
### Kubertes cli
#### How to enable port forward
```bash
$ kubectl -n dspace port-forward dspace-977584178-m9wsv 8080:8080
Forwarding from 127.0.0.1:8080 -> 8080
Forwarding from [::1]:8080 -> 8080
Handling connection for 8080
Handling connection for 8080
```
now you can connect to http://localhost:8080/repository/xmlui/

#### How to connect into pod
```bash
$ kubectl -n dspace exec -it dspace-977584178-m9wsv bash
```

## Web Server
- Substitute Apache for Ngnix.
- added env variable SHIB_HOSTNAME (pod's hostname is a pretty different concept)
- Web server's certificates are injected via secrets
- Shibboleth config pushed into container [4] 

```bash
docker run -it -p 80:80 -p 443:443 -e SHIB_HOSTNAME="lindat-dev.eurac.edu" gitlab.scientificnet.org:4567/kube/kubernetes/dspace/apache:0.1 
```

# To Do
- [1] [PostgreSQL] we need/should automatize with a entrypoint..sh script
   psudo-code:
     if exist /path/file/installed, do nothing
     else, install!
- [2] [Tomcat] write a entrypoint.sh to start tomcat
- [3] [Tomcat] use env variables in /opt/repository/sources/dspace/dspace/target/dspace-installer/config/dspace.cfg file
- [4] [Web Server] - use config map to supply Shibboleth config
